package com.hfkj.controller;

import com.alibaba.fastjson.JSONObject;
import com.hfkj.common.exception.ErrorCode;
import com.hfkj.common.exception.ErrorHelp;
import com.hfkj.common.exception.SysCode;
import com.hfkj.common.security.UserCenter;
import com.hfkj.common.utils.MemberValidateUtil;
import com.hfkj.common.utils.RedisUtil;
import com.hfkj.common.utils.ResponseMsgUtil;
import com.hfkj.model.ResponseData;
import com.hfkj.model.SecUserSessionObject;
import com.hfkj.service.user.BsUserService;
import com.hfkj.sysenum.user.UserLoginType;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.ResponseBody;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import java.util.HashMap;

/**
 * @className: ClientController
 * @author: HuRui
 * @date: 2024/9/6
 **/
@Controller
@RequestMapping(value="/client")
@Api(value="客户端业务")
public class ClientController {
    @Resource
    private BsUserService userService;
    @Resource
    private RedisUtil redisUtil;
    @Autowired
    private UserCenter userCenter;

    @RequestMapping(value = "/smsLogin", method = RequestMethod.POST)
    @ResponseBody
    @ApiOperation(value = "登录并注册 { 'phone': '手机号', 'smsCode': '短信验证码'}")
    public ResponseData smsLogin(@RequestBody JSONObject body) {
        try {
            if (body == null
                    || StringUtils.isBlank(body.getString("phone"))
                    || StringUtils.isBlank(body.getString("smsCode"))
            ) {
                throw ErrorHelp.genException(SysCode.System, ErrorCode.REQ_PARAMS_ERROR, "");
            }
            // 邀请码
            String inviteCode = body.getString("inviteCode");
            // 手机号
            String phone = body.getString("phone");
            // 校验手机号格式
            if (!MemberValidateUtil.validatePhone(phone)) {
                throw ErrorHelp.genException(SysCode.System, ErrorCode.COMMON_ERROR, "请输入正确的手机号");
            }
            if (StringUtils.isBlank(body.getString("smsCode"))) {
                throw ErrorHelp.genException(SysCode.System, ErrorCode.COMMON_ERROR, "请输入短信验证码");
            }
            // 手机号的验证码
            Object phoneCodeObject = redisUtil.get("SMS_LOGIN_CODE:" + phone);
            if (phoneCodeObject == null) {
                throw ErrorHelp.genException(SysCode.System, ErrorCode.COMMON_ERROR, "短信验证码错误");
            }
            if (!body.getString("smsCode").equals(phoneCodeObject.toString())) {
                throw ErrorHelp.genException(SysCode.System, ErrorCode.COMMON_ERROR, "短信验证码错误");
            }
            redisUtil.del("SMS_LOGIN_CODE:" + phone);

             return ResponseMsgUtil.success(userService.login(phone, UserLoginType.SMS, new HashMap<>(), inviteCode));

        } catch (Exception e) {
            return ResponseMsgUtil.exception(e);
        }
    }

    @RequestMapping(value="/loginOut",method = RequestMethod.POST)
    @ResponseBody
    @ApiOperation(value = "退出登录")
    public ResponseData loginOut(HttpServletRequest request) {
        try {
            SecUserSessionObject session = userCenter.getSessionModel(SecUserSessionObject.class);
            if (session != null) {
                userCenter.remove(request);
            }
            return ResponseMsgUtil.success("退出成功");

        } catch (Exception e) {
            return ResponseMsgUtil.exception(e);
        }
    }

}
