package com.hfkj.controller;

import com.alibaba.fastjson.JSONObject;
import com.hfkj.common.exception.ErrorCode;
import com.hfkj.common.exception.ErrorHelp;
import com.hfkj.common.exception.SysCode;
import com.hfkj.common.security.UserCenter;
import com.hfkj.common.utils.MemberValidateUtil;
import com.hfkj.common.utils.RedisUtil;
import com.hfkj.common.utils.ResponseMsgUtil;
import com.hfkj.entity.BsUser;
import com.hfkj.model.ResponseData;
import com.hfkj.model.SecUserSessionObject;
import com.hfkj.model.UserSessionObject;
import com.hfkj.service.user.BsUserService;
import com.hfkj.sysenum.user.UserLoginType;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.ResponseBody;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import java.util.HashMap;
import java.util.Map;

/**
 * @className: ClientController
 * @author: HuRui
 * @date: 2024/9/6
 **/
@Controller
@RequestMapping(value="/user")
@Api(value="客户端业务")
public class UserController {
    @Resource
    private BsUserService userService;
    @Resource
    private RedisUtil redisUtil;
    @Autowired
    private UserCenter userCenter;

    @RequestMapping(value = "/getUser", method = RequestMethod.GET)
    @ResponseBody
    @ApiOperation(value = "查询用户信息")
    public ResponseData getUser() {
        try {
            Map<String,Object> param = new HashMap<>();
            // 用户信息
            param.put("user", userCenter.getSessionModel(UserSessionObject.class));

            return ResponseMsgUtil.success(param);

        } catch (Exception e) {
            return ResponseMsgUtil.exception(e);
        }
    }

    @RequestMapping(value = "/updateWechat", method = RequestMethod.GET)
    @ResponseBody
    @ApiOperation(value = "修改用户微信号")
    public ResponseData updateWechat(@RequestBody JSONObject body) {
        try {
            if (body == null || StringUtils.isBlank(body.getString("wechatNum"))) {
                throw ErrorHelp.genException(SysCode.System, ErrorCode.REQ_PARAMS_ERROR, "");
            }
            UserSessionObject userSession = userCenter.getSessionModel(UserSessionObject.class);
            userService.updateWechatNum(userSession.getUser().getId(), body.getString("wechatNum"));
            return ResponseMsgUtil.success("操作成功");

        } catch (Exception e) {
            return ResponseMsgUtil.exception(e);
        }
    }

    @RequestMapping(value = "/bindPhone", method = RequestMethod.POST)
    @ResponseBody
    @ApiOperation(value = "绑定手机号")
    public ResponseData bindPhone(@RequestBody JSONObject body) {
        try {
            if (body == null
                    || StringUtils.isBlank(body.getString("phone"))
                    || StringUtils.isBlank(body.getString("smsCode"))) {
                throw ErrorHelp.genException(SysCode.System, ErrorCode.REQ_PARAMS_ERROR, "");
            }
            UserSessionObject userSession = userCenter.getSessionModel(UserSessionObject.class);
            if (StringUtils.isNotBlank(userSession.getUser().getPhone())) {
                throw ErrorHelp.genException(SysCode.System, ErrorCode.COMMON_ERROR, "手机号已绑定");
            }
            String phone = body.getString("phone");
            // 校验手机号格式
            if (!MemberValidateUtil.validatePhone(phone)) {
                throw ErrorHelp.genException(SysCode.System, ErrorCode.COMMON_ERROR, "请输入正确的手机号");
            }
            if (StringUtils.isBlank(body.getString("smsCode"))) {
                throw ErrorHelp.genException(SysCode.System, ErrorCode.COMMON_ERROR, "请输入短信验证码");
            }
            if (userService.getUser(phone) != null) {
                throw ErrorHelp.genException(SysCode.System, ErrorCode.COMMON_ERROR, "手机号已被绑定");
            }
            // 手机号的验证码
            Object phoneCodeObject = redisUtil.get("SMS_BIND_PHONE_CODE:" + phone);
            if (phoneCodeObject == null) {
                throw ErrorHelp.genException(SysCode.System, ErrorCode.COMMON_ERROR, "短信验证码错误");
            }
            if (!body.getString("smsCode").equals(phoneCodeObject.toString())) {
                throw ErrorHelp.genException(SysCode.System, ErrorCode.COMMON_ERROR, "短信验证码错误");
            }
            redisUtil.del("SMS_BIND_PHONE_CODE:" + phone);

            // 更新手机号
            userService.updatePhone(userSession.getUser().getId(), body.getString("phone"));

            return ResponseMsgUtil.success(userCenter.getSessionModel(UserSessionObject.class));

        } catch (Exception e) {
            return ResponseMsgUtil.exception(e);
        }
    }

    @RequestMapping(value = "/verifyUpdPhoneSmsCode", method = RequestMethod.POST)
    @ResponseBody
    @ApiOperation(value = "验证修改手机号验证码")
    public ResponseData verifyUpdPhoneSmsCode(@RequestBody JSONObject body) {
        try {
            if (body == null
                    || StringUtils.isBlank(body.getString("phone"))
                    || StringUtils.isBlank(body.getString("smsCode"))) {
                throw ErrorHelp.genException(SysCode.System, ErrorCode.REQ_PARAMS_ERROR, "");
            }
            String phone = body.getString("phone");
            // 手机号的验证码
            Object phoneCodeObject = redisUtil.get("SMS_UPDATE_PHONE_CODE:" + phone);
            if (phoneCodeObject == null) {
                throw ErrorHelp.genException(SysCode.System, ErrorCode.COMMON_ERROR, "短信验证码错误或已失效");
            }
            if (!body.getString("smsCode").equals(phoneCodeObject.toString())) {
                throw ErrorHelp.genException(SysCode.System, ErrorCode.COMMON_ERROR, "短信验证码错误或已失效");
            }
            redisUtil.del("SMS_UPDATE_PHONE_CODE:" + phone);

            return ResponseMsgUtil.success(true);

        } catch (Exception e) {
            return ResponseMsgUtil.exception(e);
        }
    }

    @RequestMapping(value = "/updatePhone", method = RequestMethod.POST)
    @ResponseBody
    @ApiOperation(value = "修改手机号")
    public ResponseData updatePhone(@RequestBody JSONObject body) {
        try {
            if (body == null
                    || StringUtils.isBlank(body.getString("newPhone"))
                    || StringUtils.isBlank(body.getString("smsCode"))) {
                throw ErrorHelp.genException(SysCode.System, ErrorCode.REQ_PARAMS_ERROR, "");
            }
            UserSessionObject userSession = userCenter.getSessionModel(UserSessionObject.class);
            if (StringUtils.isBlank(userSession.getUser().getPhone())) {
                throw ErrorHelp.genException(SysCode.System, ErrorCode.COMMON_ERROR, "用户未绑定手机号");
            }
            String phone = body.getString("newPhone");
            if (userSession.getUser().getPhone().equals(phone)) {
                throw ErrorHelp.genException(SysCode.System, ErrorCode.COMMON_ERROR, "新手机号与现绑定手机号相同");
            }
            if (userService.getUser(phone) != null) {
                throw ErrorHelp.genException(SysCode.System, ErrorCode.COMMON_ERROR, "手机号已被绑定");
            }
            // 校验手机号格式
            if (!MemberValidateUtil.validatePhone(phone)) {
                throw ErrorHelp.genException(SysCode.System, ErrorCode.COMMON_ERROR, "请输入正确的手机号");
            }
            if (StringUtils.isBlank(body.getString("smsCode"))) {
                throw ErrorHelp.genException(SysCode.System, ErrorCode.COMMON_ERROR, "请输入短信验证码");
            }
            // 手机号的验证码
            Object phoneCodeObject = redisUtil.get("SMS_UPDATE_PHONE_CODE:" + phone);
            if (phoneCodeObject == null) {
                throw ErrorHelp.genException(SysCode.System, ErrorCode.COMMON_ERROR, "短信验证码错误或已失效");
            }
            if (!body.getString("smsCode").equals(phoneCodeObject.toString())) {
                throw ErrorHelp.genException(SysCode.System, ErrorCode.COMMON_ERROR, "短信验证码错误或已失效");
            }
            redisUtil.del("SMS_UPDATE_PHONE_CODE:" + phone);

            // 更新手机号
            userService.updatePhone(userSession.getUser().getId(), body.getString("phone"));

            return ResponseMsgUtil.success(userCenter.getSessionModel(UserSessionObject.class));

        } catch (Exception e) {
            return ResponseMsgUtil.exception(e);
        }
    }

}
