package com.hfkj.service.user.impl;

import com.hfkj.common.QRCodeGenerator;
import com.hfkj.common.utils.RandomUtils;
import com.hfkj.common.utils.RedisUtil;
import com.hfkj.config.CommonSysConfig;
import com.hfkj.config.CommonSysConst;
import com.hfkj.dao.BsUserInviteCodeMapper;
import com.hfkj.entity.BsUserInviteCode;
import com.hfkj.entity.BsUserInviteCodeExample;
import com.hfkj.service.user.BsUserInviteCodeService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.Date;
import java.util.List;

/**
 * @className: UserInviteCodeServiceImpl
 * @author: HuRui
 * @date: 2024/9/9
 **/
@Service("userInviteCodeService")
public class BsUserInviteCodeServiceImpl implements BsUserInviteCodeService {
    @Resource
    private BsUserInviteCodeMapper userInviteCodeMapper;
    @Resource
    private RedisUtil redisUtil;
    @Autowired
    private CommonSysConfig commonSysConfig;
    private final static String CACHE_KEY = "USER_INVITE_CODE";

    private String generateInviteCode() {
        // 生成8位随机数
        String inviteCode = RandomUtils.number(8, true);
        // 查询是否存在，存在就重新生成
        if (getDetail(inviteCode) != null) {
            generateInviteCode();
        }
        return inviteCode;
    }


    @Override
    public BsUserInviteCode create(Long userId) throws Exception {
        BsUserInviteCode data = new BsUserInviteCode();
        data.setUserId(userId);
        data.setInviteCode(generateInviteCode());
        data.setCreateTime(new Date());
        data.setStatus(1);
        System.out.println(commonSysConfig.getDomain());
        // 生成二维码
        String fileUrl = "/userInviteCode/"+data.getInviteCode()+".png";
        QRCodeGenerator.generateQRCodeImage(
                data.getInviteCode(),
                260,
                260,
                commonSysConfig.getFilesystem() + fileUrl
        );
        // 背景图
        // QRCodeGenerator.overlapImage(fileUrl, "/template/qrCodeBackdrop1_1.png",740,110);
        data.setQrCodeImg(fileUrl);
        userInviteCodeMapper.insert(data);
        // 缓存
        redisUtil.hset(CACHE_KEY, data.getInviteCode(), data);
        return data;
    }


    @Override
    public BsUserInviteCode getDetail(Long userId) {
        BsUserInviteCodeExample example = new BsUserInviteCodeExample();
        example.createCriteria().andUserIdEqualTo(userId).andStatusNotEqualTo(0);
        List<BsUserInviteCode> list = userInviteCodeMapper.selectByExample(example);
        if (!list.isEmpty()) {
            return list.get(0);
        }
        return null;
    }

    @Override
    public BsUserInviteCode getDetail(String inviteCode) {
        // 缓存
        Object cache = redisUtil.hget(CACHE_KEY, inviteCode);
        if (cache != null) {
            return (BsUserInviteCode) cache;
        }
        BsUserInviteCodeExample example = new BsUserInviteCodeExample();
        example.createCriteria().andInviteCodeEqualTo(inviteCode).andStatusNotEqualTo(0);
        List<BsUserInviteCode> list = userInviteCodeMapper.selectByExample(example);
        if (!list.isEmpty()) {
            BsUserInviteCode data = list.get(0);
            // 缓存
            redisUtil.hset(CACHE_KEY, data.getInviteCode(), data);
            return data;
        }
        return null;
    }
}
